@@ -1,9 +1,8 @@
 from sleepyask.openai.chatgpt import ask_questions
 import traceback
 import logging
-import time
 
-def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False, model : str = "gpt-3.5-turbo", system_text : str = None):
+def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False, model : str = "gpt-3.5-turbo", system_text : str | None = None, temperature : float | None = 1, max_tokens : int | None = 2048):
     '''
     `config` should be a list containing your ChatGPT access tokens / email and password\n
     `questions` should contain a list of questions you would like ChatGPT to answer.\n
@@ -13,9 +12,6 @@ def ask(configs : list, questions : list, output_file_path : str, verbose: bool
     while redo:
         if not isinstance(questions, list): raise ValueError("[questions] should be a list")
 
-        try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose, model=model, system_text=system_text)
+        try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose, model=model, system_text=system_text, temperature=temperature, max_tokens=max_tokens)
         except Exception as e: 
-            logging.error(traceback.format_exc())
-        
-        time.sleep(60)
-        
\ No newline at end of file
+            logging.error(traceback.format_exc())
\ No newline at end of file
